# == Class: ocsinventory_agent::apt
#
# Installation of ocsinventory_agent when provider is apt
#
# === Authors
#
# Fran Lois Rua <franlr@gmail.com>
#
# === Copyright
#
# Copyright 2014 Fran Lois Rua, unless otherwise noted.
#
class ocsinventory_agent::apt (
  $ensure     = $ocsinventory_agent::ensure,
  $ocspackage = $ocsinventory_agent::ocspackage,
  $method     = $ocsinventory_agent::method,
  $server     = $ocsinventory_agent::server,
  $ocstag     = $ocsinventory_agent::ocstag,
  $source     = $ocsinventory_agent::source,
) inherits ocsinventory_agent {

  $temp_path = "/tmp/ocsinventory-agent.seed"
  validate_absolute_path($temp_path)
  
  file { "$temp_path":
    path     => "$temp_path",
    ensure   => $ensure,
    checksum => 'md5',
    mode     => '0644',
    owner    => 'root',
    group    => 'root',
    content  => template('ocsinventory_agent/ocsinventory-agent.seed.erb'),
    before   => Debconf_package["$ocspackage"],
  }

  if ! defined(Package[ "$ocspackage" ]) {
    debconf_package { $ocspackage:
      ensure => $ensure,
      source => "$temp_path",
    }
  }
  
  exec { 'ocs_first_run':
    path        => [ '/usr/bin/', '/bin/', '/usr/lib/', '/usr/local/lib/' ],
    command     => "ocsinventory-agent --force",
    onlyif      => "dpkg -l | grep -c $ocspackage",
    require     => Debconf_package["$ocspackage"],
    refreshonly => true,
  }
  
}
