# == Class: ocsinventory_agent
#
# Main class to install the ocsinventory agent on Debian computers
#
# === Parameters
#
# Document parameters here.
#
# [*ensure*]
#   _default_: +present+
#   This tells the module to add or purge the agent from the machine
#
# [*provider*]
#   _default_: +apt+
#   Use the distribution package or compile from source donwloaded from the web
#
# [*ocspackage*]
#   _default_: +ocsinventory-agent+
#   The package name
#
# [*version*]
#   _default_: +2.0.5+
#   The package version
#
# [*type*]
#   _default_: +agent+
#   If agent or server type.
#
# [*method*]
#   _default_: +http+
#   Two options for the ocs reporting: http or local
#
# [*server*]
#   _default_: +ocsreports.domain.name+
#   The ocs server name
#
# [*ocstag*]
#   _default_: +ocstag+
#   The tag field of the ocs report entry
#
# [*source*]
#   _default_: +modules/ocsinventory_agent/ocsinventory-agent.seed+
#   The path to the seed file when *provider* is +source+ (not implemented yet)
#
# === Examples
#
#  class { 'ocsinventory_agent':
#    server => "ocsserver.domain.name",
#  }
#
# === Authors
#
# Fran Lois Rua <franlr@gmail.com>
#
# === Copyright
#
# Copyright 2014 Fran Lois Rua, unless otherwise noted.
#
class ocsinventory_agent (
  $ensure     = $ocsinventory_agent::params::ensure,
  $provider   = $ocsinventory_agent::params::provider,
  $ocspackage = $ocsinventory_agent::params::ocspackage,
  $version    = $ocsinventory_agent::params::version,
  $type       = $ocsinventory_agent::params::type,
  $method     = $ocsinventory_agent::params::method,
  $server     = $ocsinventory_agent::params::server,
  $ocstag     = $ocsinventory_agent::params::ocstag,
  $source     = $ocsinventory_agent::params::source,
) inherits ocsinventory_agent::params {

  validate_string($provider)
  validate_string($ocspackage)
  validate_string($type)
  validate_re($server, '^.domain.name$', 'The $server name does not match with the right domain')
  validate_string($ocstag)
  validate_string($method)

  case $::osfamily {
    'Debian': {
      if $::ocsinventory_agent::provider == "apt" {
        include ocsinventory_agent::apt
      }
    }
    default: {
      fail("\$osfamily ${::osfamily} is not supported by the ${module_name} module.")
    }
  }
}
